/**
 * @file webpack.config.dev.js
 * @author lihuazhai
 */
"use strict";

const path = require('path');
const merge = require('webpack-merge');
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const { CleanWebpackPlugin } = require('clean-webpack-plugin');

const baseConfig = require('./webpack.base.js');

const devConfig = merge.smart(baseConfig, {
    devtool: true,
    devtool: 'eval-source-map',
    // 服务配置
    devServer: {
        contentBase: path.join(__dirname, 'dist'), //网站的根目录为 根目录/dist
        host: '127.0.0.1',
        port: 3000,
        hot: true,
        // host: '192.168.0.103', //如果指定的host，这样同局域网的电脑或手机可以访问该网站,host的值在dos下使用ipconfig获取 
        open: true, // 自动打开浏览器
        compress: true, //压缩
        proxy: {
            // '/api': {
            //     target: "http://127.0.0.1:8989",
            //     changeOrigin: true,
            //     pathRewrite: {
            //         '^/api': ''
            //     }
            // },
            '/api': {
                target: "http://127.0.0.1:8085",
                changeOrigin: true
            }
        },
        historyApiFallback: {
            disableDotRule: true,
            // 指明哪些路径映射到哪个html
            rewrites: [
                { from: /^\/admin.html/, to: '/dist/admin/admin.html' },
            ]
        }
    },
    plugins: [
        new webpack.ProgressPlugin(),
        new HtmlWebpackPlugin({
            title: '梨花寨',
            filename: 'index.html',
            template: './src/layout.tpl.html',
            hash: true, // 会在打包好的bundle.js后面加上hash串
            overlay: true, // 这个配置属性用来在编译出错的时候，在浏览器页面上显示错误
            inject: true,
            chunks: ['index']
        })
    ]

});

module.exports = devConfig;